@@ -1,22 +1,8 @@
 /* kmfl_interpreter.c
- * Copyright (C) 2005 SIL International and Tavultesoft Pty Ltd
+ * Copyright (C) 2005 SIL International
  *
  * This file is part of the KMFL library.
  *
- * The KMFL library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * The KMFL library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with the KMFL library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
  */
 
 /*
@@ -94,7 +80,6 @@ int kmfl_interpret(KMSI *p_kmsi, UINT key, UINT state)
 	XKEYBOARD *p_kbd;
 	XGROUP *p_group1;
 	ITEM keysym;
-	int matched;
 
 	p_kmsi->noutput_queue=0;
 	
@@ -264,7 +249,7 @@ int match_rule(KMSI *p_kmsi, XRULE *rp, ITEM *any_index, int usekeys)
 {
 	
 	UINT k, m, n, nmax, rulelen, nhistory, index;
-	ITEM *pr, *ph, *ps, mask;
+	ITEM *pr, *ph, *ps;
 
 	rulelen = rp->ilen;
 	pr = p_kmsi->strings+rp->lhs;
@@ -365,7 +350,7 @@ int process_rule(KMSI *p_kmsi, XRULE *rp, ITEM *any_index, int usekeys)
 	XGROUP *gp;
 	UINT i, k, m, n, nout, itp, index;
 	ITEM *p, *pr, *ps, output[MAX_OUTPUT+1], history[MAX_HISTORY], *it;
-	int erase, result, retCode=1, nhistory;
+	int erase, retCode=1, nhistory;
 
 	DBGMSG(1, "DAR - libkmfl - process_rule\n");
 	pr = p_kmsi->strings+rp->rhs;	// Pointer to start of output rule
@@ -753,7 +738,7 @@ int kmfl_get_header(KMSI *p_kmsi,int hdrID,char *buf,int buflen)
 
 	if(!p_kmsi) return -1;
 
-	if(hdrID < 0 || hdrID > SS_AUTHOR) return -2;
+	if(hdrID < 0 || hdrID > SS_KEYBOARDVERSION) return -2;
 
 	p32 = (UTF32 *)store_content(p_kmsi,hdrID);
 	p8 = (UTF8 *)buf;
